@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2019, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -17,7 +17,7 @@
 #include "aom_dsp/quantize.h"
 #include "aom_dsp/x86/quantize_x86.h"
 
-static INLINE void highbd_load_b_values_avx2(
+static inline void highbd_load_b_values_avx2(
     const int16_t *zbin_ptr, __m256i *zbin, const int16_t *round_ptr,
     __m256i *round, const int16_t *quant_ptr, __m256i *quant,
     const int16_t *dequant_ptr, __m256i *dequant, const int16_t *shift_ptr,
@@ -31,7 +31,7 @@ static INLINE void highbd_load_b_values_avx2(
   *shift = _mm256_cvtepi16_epi32(_mm_load_si128((const __m128i *)shift_ptr));
 }
 
-static INLINE void highbd_update_mask1_avx2(__m256i *cmp_mask,
+static inline void highbd_update_mask1_avx2(__m256i *cmp_mask,
                                             const int16_t *iscan_ptr,
                                             int *is_found, __m256i *mask) {
   __m256i temp_mask = _mm256_setzero_si256();
@@ -43,7 +43,7 @@ static INLINE void highbd_update_mask1_avx2(__m256i *cmp_mask,
   *mask = _mm256_max_epi16(temp_mask, *mask);
 }
 
-static INLINE void highbd_update_mask0_avx2(__m256i *qcoeff0, __m256i *qcoeff1,
+static inline void highbd_update_mask0_avx2(__m256i *qcoeff0, __m256i *qcoeff1,
                                             __m256i *threshold,
                                             const int16_t *iscan_ptr,
                                             int *is_found, __m256i *mask) {
@@ -57,7 +57,7 @@ static INLINE void highbd_update_mask0_avx2(__m256i *qcoeff0, __m256i *qcoeff1,
   highbd_update_mask1_avx2(&cmp_mask0, iscan_ptr, is_found, mask);
 }
 
-static INLINE void highbd_mul_shift_avx2(const __m256i *x, const __m256i *y,
+static inline void highbd_mul_shift_avx2(const __m256i *x, const __m256i *y,
                                          __m256i *p, const int shift) {
   __m256i prod_lo = _mm256_mul_epi32(*x, *y);
   __m256i prod_hi = _mm256_srli_epi64(*x, 32);
@@ -71,7 +71,7 @@ static INLINE void highbd_mul_shift_avx2(const __m256i *x, const __m256i *y,
   *p = _mm256_blend_epi32(prod_lo, prod_hi, 0xaa);
 }
 
-static INLINE void highbd_calculate_qcoeff_avx2(__m256i *coeff,
+static inline void highbd_calculate_qcoeff_avx2(__m256i *coeff,
                                                 const __m256i *round,
                                                 const __m256i *quant,
                                                 const __m256i *shift,
@@ -83,19 +83,19 @@ static INLINE void highbd_calculate_qcoeff_avx2(__m256i *coeff,
   highbd_mul_shift_avx2(&qcoeff, shift, coeff, 16 - *log_scale);
 }
 
-static INLINE __m256i highbd_calculate_dqcoeff_avx2(__m256i qcoeff,
+static inline __m256i highbd_calculate_dqcoeff_avx2(__m256i qcoeff,
                                                     __m256i dequant) {
   return _mm256_mullo_epi32(qcoeff, dequant);
 }
 
-static INLINE __m256i highbd_calculate_dqcoeff_log_scale_avx2(
+static inline __m256i highbd_calculate_dqcoeff_log_scale_avx2(
     __m256i qcoeff, __m256i dequant, const int log_scale) {
   __m256i abs_coeff = _mm256_abs_epi32(qcoeff);
   highbd_mul_shift_avx2(&abs_coeff, &dequant, &abs_coeff, log_scale);
   return _mm256_sign_epi32(abs_coeff, qcoeff);
 }
 
-static INLINE void highbd_store_coefficients_avx2(__m256i coeff0,
+static inline void highbd_store_coefficients_avx2(__m256i coeff0,
                                                   __m256i coeff1,
                                                   tran_low_t *coeff_ptr) {
   _mm256_store_si256((__m256i *)(coeff_ptr), coeff0);
