@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2023, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2023, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -19,7 +19,10 @@ DECLARE_ALIGNED(16, static const uint8_t, usdot_permute_idx[48]) = {
 
 static AOM_FORCE_INLINE int16x8_t horizontal_filter_4x1_f4(const uint8x16_t in,
                                                            int sx, int alpha) {
-  const int32x4_t add_const = vdupq_n_s32(1 << (8 + FILTER_BITS - 1));
+  // Only put the constant in every other lane to avoid double-counting when
+  // performing the pairwise add later.
+  const int32x4_t add_const =
+      vreinterpretq_s32_u64(vdupq_n_u64(1 << (8 + FILTER_BITS - 1)));
 
   // Loading the 8 filter taps
   int16x8_t f[4];
@@ -33,21 +36,22 @@ static AOM_FORCE_INLINE int16x8_t horizontal_filter_4x1_f4(const uint8x16_t in,
   uint8x8_t in2 = vget_low_u8(vextq_u8(in, in, 2));
   uint8x8_t in3 = vget_low_u8(vextq_u8(in, in, 3));
 
-  int32x4_t m01 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in0, in1), f01_u8);
-  int32x4_t m23 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in2, in3), f23_u8);
+  int32x4_t m01 = vusdotq_s32(add_const, vcombine_u8(in0, in1), f01_u8);
+  int32x4_t m23 = vusdotq_s32(add_const, vcombine_u8(in2, in3), f23_u8);
 
-  int32x4_t tmp_res_low = vpaddq_s32(m01, m23);
-
-  tmp_res_low = vaddq_s32(tmp_res_low, add_const);
+  int32x4_t m0123 = vpaddq_s32(m01, m23);
 
   uint16x8_t res =
-      vcombine_u16(vqrshrun_n_s32(tmp_res_low, ROUND0_BITS), vdup_n_u16(0));
+      vcombine_u16(vqrshrun_n_s32(m0123, ROUND0_BITS), vdup_n_u16(0));
   return vreinterpretq_s16_u16(res);
 }
 
 static AOM_FORCE_INLINE int16x8_t horizontal_filter_8x1_f8(const uint8x16_t in,
                                                            int sx, int alpha) {
-  const int32x4_t add_const = vdupq_n_s32(1 << (8 + FILTER_BITS - 1));
+  // Only put the constant in every other lane to avoid double-counting when
+  // performing the pairwise add later.
+  const int32x4_t add_const =
+      vreinterpretq_s32_u64(vdupq_n_u64(1 << (8 + FILTER_BITS - 1)));
 
   // Loading the 8 filter taps
   int16x8_t f[8];
@@ -67,29 +71,23 @@ static AOM_FORCE_INLINE int16x8_t horizontal_filter_8x1_f8(const uint8x16_t in,
   uint8x8_t in6 = vget_low_u8(vextq_u8(in, in, 6));
   uint8x8_t in7 = vget_low_u8(vextq_u8(in, in, 7));
 
-  int32x4_t m01 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in0, in1), f01_u8);
-  int32x4_t m23 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in2, in3), f23_u8);
-  int32x4_t m45 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in4, in5), f45_u8);
-  int32x4_t m67 = vusdotq_s32(vdupq_n_s32(0), vcombine_u8(in6, in7), f67_u8);
+  int32x4_t m01 = vusdotq_s32(add_const, vcombine_u8(in0, in1), f01_u8);
+  int32x4_t m23 = vusdotq_s32(add_const, vcombine_u8(in2, in3), f23_u8);
+  int32x4_t m45 = vusdotq_s32(add_const, vcombine_u8(in4, in5), f45_u8);
+  int32x4_t m67 = vusdotq_s32(add_const, vcombine_u8(in6, in7), f67_u8);
 
-  int32x4_t tmp_res_low = vpaddq_s32(m01, m23);
-  int32x4_t tmp_res_high = vpaddq_s32(m45, m67);
+  int32x4_t m0123 = vpaddq_s32(m01, m23);
+  int32x4_t m4567 = vpaddq_s32(m45, m67);
 
-  tmp_res_low = vaddq_s32(tmp_res_low, add_const);
-  tmp_res_high = vaddq_s32(tmp_res_high, add_const);
-
-  uint16x8_t res = vcombine_u16(vqrshrun_n_s32(tmp_res_low, ROUND0_BITS),
-                                vqrshrun_n_s32(tmp_res_high, ROUND0_BITS));
+  uint16x8_t res = vcombine_u16(vqrshrun_n_s32(m0123, ROUND0_BITS),
+                                vqrshrun_n_s32(m4567, ROUND0_BITS));
   return vreinterpretq_s16_u16(res);
 }
 
-static AOM_FORCE_INLINE int16x8_t horizontal_filter_4x1_f1(const uint8x16_t in,
-                                                           int sx) {
+static AOM_FORCE_INLINE int16x8_t
+horizontal_filter_4x1_f1_beta0(const uint8x16_t in, int16x8_t f_s16) {
   const int32x4_t add_const = vdupq_n_s32(1 << (8 + FILTER_BITS - 1));
 
-  int16x8_t f_s16 =
-      vld1q_s16((int16_t *)(av1_warped_filter + (sx >> WARPEDDIFF_PREC_BITS)));
-
   int8x16_t f_s8 = vcombine_s8(vmovn_s16(f_s16), vmovn_s16(f_s16));
 
   uint8x16_t perm0 = vld1q_u8(&usdot_permute_idx[0]);
@@ -101,24 +99,23 @@ static AOM_FORCE_INLINE int16x8_t horizontal_filter_4x1_f1(const uint8x16_t in,
   uint8x16_t in_0123 = vqtbl1q_u8(in, perm0);
   uint8x16_t in_4567 = vqtbl1q_u8(in, perm1);
 
-  int32x4_t m0123 = vusdotq_laneq_s32(vdupq_n_s32(0), in_0123, f_s8, 0);
+  int32x4_t m0123 = vusdotq_laneq_s32(add_const, in_0123, f_s8, 0);
   m0123 = vusdotq_laneq_s32(m0123, in_4567, f_s8, 1);
 
-  int32x4_t tmp_res_low = m0123;
-
-  tmp_res_low = vaddq_s32(tmp_res_low, add_const);
-
   uint16x8_t res =
-      vcombine_u16(vqrshrun_n_s32(tmp_res_low, ROUND0_BITS), vdup_n_u16(0));
+      vcombine_u16(vqrshrun_n_s32(m0123, ROUND0_BITS), vdup_n_u16(0));
   return vreinterpretq_s16_u16(res);
 }
 
-static AOM_FORCE_INLINE int16x8_t horizontal_filter_8x1_f1(const uint8x16_t in,
+static AOM_FORCE_INLINE int16x8_t horizontal_filter_4x1_f1(const uint8x16_t in,
                                                            int sx) {
-  const int32x4_t add_const = vdupq_n_s32(1 << (8 + FILTER_BITS - 1));
+  int16x8_t f_s16 = vld1q_s16(av1_warped_filter[sx >> WARPEDDIFF_PREC_BITS]);
+  return horizontal_filter_4x1_f1_beta0(in, f_s16);
+}
 
-  int16x8_t f_s16 =
-      vld1q_s16((int16_t *)(av1_warped_filter + (sx >> WARPEDDIFF_PREC_BITS)));
+static AOM_FORCE_INLINE int16x8_t
+horizontal_filter_8x1_f1_beta0(const uint8x16_t in, int16x8_t f_s16) {
+  const int32x4_t add_const = vdupq_n_s32(1 << (8 + FILTER_BITS - 1));
 
   int8x16_t f_s8 = vcombine_s8(vmovn_s16(f_s16), vmovn_s16(f_s16));
 
@@ -134,23 +131,23 @@ static AOM_FORCE_INLINE int16x8_t horizontal_filter_8x1_f1(const uint8x16_t in,
   uint8x16_t in_4567 = vqtbl1q_u8(in, perm1);
   uint8x16_t in_89ab = vqtbl1q_u8(in, perm2);
 
-  int32x4_t m0123 = vusdotq_laneq_s32(vdupq_n_s32(0), in_0123, f_s8, 0);
+  int32x4_t m0123 = vusdotq_laneq_s32(add_const, in_0123, f_s8, 0);
   m0123 = vusdotq_laneq_s32(m0123, in_4567, f_s8, 1);
 
-  int32x4_t m4567 = vusdotq_laneq_s32(vdupq_n_s32(0), in_4567, f_s8, 0);
+  int32x4_t m4567 = vusdotq_laneq_s32(add_const, in_4567, f_s8, 0);
   m4567 = vusdotq_laneq_s32(m4567, in_89ab, f_s8, 1);
 
-  int32x4_t tmp_res_low = m0123;
-  int32x4_t tmp_res_high = m4567;
-
-  tmp_res_low = vaddq_s32(tmp_res_low, add_const);
-  tmp_res_high = vaddq_s32(tmp_res_high, add_const);
-
-  uint16x8_t res = vcombine_u16(vqrshrun_n_s32(tmp_res_low, ROUND0_BITS),
-                                vqrshrun_n_s32(tmp_res_high, ROUND0_BITS));
+  uint16x8_t res = vcombine_u16(vqrshrun_n_s32(m0123, ROUND0_BITS),
+                                vqrshrun_n_s32(m4567, ROUND0_BITS));
   return vreinterpretq_s16_u16(res);
 }
 
+static AOM_FORCE_INLINE int16x8_t horizontal_filter_8x1_f1(const uint8x16_t in,
+                                                           int sx) {
+  int16x8_t f_s16 = vld1q_s16(av1_warped_filter[sx >> WARPEDDIFF_PREC_BITS]);
+  return horizontal_filter_8x1_f1_beta0(in, f_s16);
+}
+
 static AOM_FORCE_INLINE void vertical_filter_4x1_f1(const int16x8_t *src,
                                                     int32x4_t *res, int sy) {
   int16x4_t s0 = vget_low_s16(src[0]);
@@ -162,8 +159,7 @@ static AOM_FORCE_INLINE void vertical_filter_4x1_f1(const int16x8_t *src,
   int16x4_t s6 = vget_low_s16(src[6]);
   int16x4_t s7 = vget_low_s16(src[7]);
 
-  int16x8_t f =
-      vld1q_s16((int16_t *)(av1_warped_filter + (sy >> WARPEDDIFF_PREC_BITS)));
+  int16x8_t f = vld1q_s16(av1_warped_filter[sy >> WARPEDDIFF_PREC_BITS]);
 
   int32x4_t m0123 = vmull_lane_s16(s0, vget_low_s16(f), 0);
   m0123 = vmlal_lane_s16(m0123, s1, vget_low_s16(f), 1);
@@ -216,8 +212,7 @@ static AOM_FORCE_INLINE void vertical_filter_8x1_f1(const int16x8_t *src,
   int16x8_t s6 = src[6];
   int16x8_t s7 = src[7];
 
-  int16x8_t f =
-      vld1q_s16((int16_t *)(av1_warped_filter + (sy >> WARPEDDIFF_PREC_BITS)));
+  int16x8_t f = vld1q_s16(av1_warped_filter[sy >> WARPEDDIFF_PREC_BITS]);
 
   int32x4_t m0123 = vmull_lane_s16(vget_low_s16(s0), vget_low_s16(f), 0);
   m0123 = vmlal_lane_s16(m0123, vget_low_s16(s1), vget_low_s16(f), 1);
