@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -56,13 +56,6 @@ int av1_get_mvpred_sse(const MV_COST_PARAMS *mv_cost_params,
                        const FULLPEL_MV best_mv,
                        const aom_variance_fn_ptr_t *vfp,
                        const struct buf_2d *src, const struct buf_2d *pre);
-int av1_get_mvpred_compound_var(const MV_COST_PARAMS *ms_params,
-                                const FULLPEL_MV best_mv,
-                                const uint8_t *second_pred, const uint8_t *mask,
-                                int mask_stride, int invert_mask,
-                                const aom_variance_fn_ptr_t *vfp,
-                                const struct buf_2d *src,
-                                const struct buf_2d *pre);
 
 // =============================================================================
 //  Motion Search
@@ -83,7 +76,7 @@ typedef struct {
   const int32_t *obmc_mask;
 } MSBuffers;
 
-static INLINE void av1_set_ms_compound_refs(MSBuffers *ms_buffers,
+static inline void av1_set_ms_compound_refs(MSBuffers *ms_buffers,
                                             const uint8_t *second_pred,
                                             const uint8_t *mask,
                                             int mask_stride, int invert_mask) {
@@ -158,24 +151,8 @@ void av1_make_default_fullpel_ms_params(
 void av1_set_ms_to_intra_mode(FULLPEL_MOTION_SEARCH_PARAMS *ms_params,
                               const IntraBCMVCosts *dv_costs);
 
-// Sets up configs for fullpixel DIAMOND / CLAMPED_DIAMOND search method.
-void av1_init_dsmotion_compensation(search_site_config *cfg, int stride,
-                                    int level);
 // Sets up configs for firstpass motion search.
 void av1_init_motion_fpf(search_site_config *cfg, int stride);
-// Sets up configs for NSTEP / NSTEP_8PT motion search method.
-void av1_init_motion_compensation_nstep(search_site_config *cfg, int stride,
-                                        int level);
-// Sets up configs for BIGDIA / FAST_DIAMOND / FAST_BIGDIA
-// motion search method.
-void av1_init_motion_compensation_bigdia(search_site_config *cfg, int stride,
-                                         int level);
-// Sets up configs for HEX or FAST_HEX motion search method.
-void av1_init_motion_compensation_hex(search_site_config *cfg, int stride,
-                                      int level);
-// Sets up configs for SQUARE motion search method.
-void av1_init_motion_compensation_square(search_site_config *cfg, int stride,
-                                         int level);
 
 /*! Function pointer to search site config initialization of different search
  * method functions. */
@@ -203,7 +180,7 @@ static const SEARCH_METHODS search_method_lookup[NUM_SEARCH_METHODS] = {
 };
 
 // Reinitialize the search site config.
-static AOM_INLINE void av1_refresh_search_site_config(
+static inline void av1_refresh_search_site_config(
     search_site_config *ss_cfg_buf, SEARCH_METHODS search_method,
     const int ref_stride) {
   const int level =
@@ -214,7 +191,7 @@ static AOM_INLINE void av1_refresh_search_site_config(
 }
 
 // Mv beyond the range do not produce new/different prediction block.
-static INLINE void av1_set_mv_search_method(
+static inline void av1_set_mv_search_method(
     FULLPEL_MOTION_SEARCH_PARAMS *ms_params,
     const search_site_config search_sites[NUM_DISTINCT_SEARCH_METHODS],
     SEARCH_METHODS search_method) {
@@ -225,7 +202,7 @@ static INLINE void av1_set_mv_search_method(
 
 // Set up limit values for MV components.
 // Mv beyond the range do not produce new/different prediction block.
-static INLINE void av1_set_mv_row_limits(
+static inline void av1_set_mv_row_limits(
     const CommonModeInfoParams *const mi_params, FullMvLimits *mv_limits,
     int mi_row, int mi_height, int border) {
   const int min1 = -(mi_row * MI_SIZE + border - 2 * AOM_INTERP_EXTEND);
@@ -238,7 +215,7 @@ static INLINE void av1_set_mv_row_limits(
   mv_limits->row_max = AOMMIN(max1, max2);
 }
 
-static INLINE void av1_set_mv_col_limits(
+static inline void av1_set_mv_col_limits(
     const CommonModeInfoParams *const mi_params, FullMvLimits *mv_limits,
     int mi_col, int mi_width, int border) {
   const int min1 = -(mi_col * MI_SIZE + border - 2 * AOM_INTERP_EXTEND);
@@ -251,7 +228,7 @@ static INLINE void av1_set_mv_col_limits(
   mv_limits->col_max = AOMMIN(max1, max2);
 }
 
-static INLINE void av1_set_mv_limits(
+static inline void av1_set_mv_limits(
     const CommonModeInfoParams *const mi_params, FullMvLimits *mv_limits,
     int mi_row, int mi_col, int mi_height, int mi_width, int border) {
   av1_set_mv_row_limits(mi_params, mv_limits, mi_row, mi_height, border);
@@ -262,6 +239,9 @@ void av1_set_mv_search_range(FullMvLimits *mv_limits, const MV *mv);
 
 int av1_init_search_range(int size);
 
+int av1_vector_match(const int16_t *ref, const int16_t *src, int bwl,
+                     int search_size, int full_search, int *sad);
+
 unsigned int av1_int_pro_motion_estimation(
     const struct AV1_COMP *cpi, MACROBLOCK *x, BLOCK_SIZE bsize, int mi_row,
     int mi_col, const MV *ref_mv, unsigned int *y_sad_zero,
@@ -285,7 +265,7 @@ int av1_obmc_full_pixel_search(const FULLPEL_MV start_mv,
                                const FULLPEL_MOTION_SEARCH_PARAMS *ms_params,
                                const int step_param, FULLPEL_MV *best_mv);
 
-static INLINE int av1_is_fullmv_in_range(const FullMvLimits *mv_limits,
+static inline int av1_is_fullmv_in_range(const FullMvLimits *mv_limits,
                                          FULLPEL_MV mv) {
   return (mv.col >= mv_limits->col_min) && (mv.col <= mv_limits->col_max) &&
          (mv.row >= mv_limits->row_min) && (mv.row <= mv_limits->row_max);
@@ -352,13 +332,13 @@ unsigned int av1_refine_warped_mv(MACROBLOCKD *xd, const AV1_COMMON *const cm,
                                   WARP_SEARCH_METHOD search_method,
                                   int num_iterations);
 
-static INLINE void av1_set_fractional_mv(int_mv *fractional_best_mv) {
+static inline void av1_set_fractional_mv(int_mv *fractional_best_mv) {
   for (int z = 0; z < 3; z++) {
     fractional_best_mv[z].as_int = INVALID_MV;
   }
 }
 
-static INLINE void av1_set_subpel_mv_search_range(SubpelMvLimits *subpel_limits,
+static inline void av1_set_subpel_mv_search_range(SubpelMvLimits *subpel_limits,
                                                   const FullMvLimits *mv_limits,
                                                   const MV *ref_mv) {
   const int max_mv = GET_MV_SUBPEL(MAX_FULL_PEL_VAL);
@@ -376,17 +356,17 @@ static INLINE void av1_set_subpel_mv_search_range(SubpelMvLimits *subpel_limits,
   subpel_limits->row_max = AOMMIN(MV_UPP - 1, maxr);
 }
 
-static INLINE int av1_is_subpelmv_in_range(const SubpelMvLimits *mv_limits,
+static inline int av1_is_subpelmv_in_range(const SubpelMvLimits *mv_limits,
                                            MV mv) {
   return (mv.col >= mv_limits->col_min) && (mv.col <= mv_limits->col_max) &&
          (mv.row >= mv_limits->row_min) && (mv.row <= mv_limits->row_max);
 }
 
-static INLINE int get_offset_from_fullmv(const FULLPEL_MV *mv, int stride) {
+static inline int get_offset_from_fullmv(const FULLPEL_MV *mv, int stride) {
   return mv->row * stride + mv->col;
 }
 
-static INLINE const uint8_t *get_buf_from_fullmv(const struct buf_2d *buf,
+static inline const uint8_t *get_buf_from_fullmv(const struct buf_2d *buf,
                                                  const FULLPEL_MV *mv) {
   return &buf->buf[get_offset_from_fullmv(mv, buf->stride)];
 }
