@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -14,12 +14,13 @@
 
 #include <limits.h>
 
+#include "aom/aomcx.h"
 #include "av1/common/blockd.h"
-
 #include "av1/encoder/block.h"
 #include "av1/encoder/context_tree.h"
 #include "av1/encoder/cost.h"
 #include "av1/encoder/ratectrl.h"
+#include "config/aom_config.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -56,6 +57,38 @@ extern "C" {
 // Factor to weigh the rate for switchable interp filters.
 #define SWITCHABLE_INTERP_RATE_FACTOR 1
 
+// Macros for common video resolutions: width x height
+// For example, 720p represents video resolution of 1280x720 pixels.
+#define RESOLUTION_288P 352 * 288
+#define RESOLUTION_360P 640 * 360
+#define RESOLUTION_480P 640 * 480
+#define RESOLUTION_720P 1280 * 720
+#define RESOLUTION_1080P 1920 * 1080
+#define RESOLUTION_1440P 2560 * 1440
+#define RESOLUTION_4K 3840 * 2160
+
+#define RTC_REFS 4
+static const MV_REFERENCE_FRAME real_time_ref_combos[RTC_REFS][2] = {
+  { LAST_FRAME, NONE_FRAME },
+  { ALTREF_FRAME, NONE_FRAME },
+  { GOLDEN_FRAME, NONE_FRAME },
+  { INTRA_FRAME, NONE_FRAME }
+};
+
+static inline int mode_offset(const PREDICTION_MODE mode) {
+  if (mode >= NEARESTMV) {
+    return INTER_OFFSET(mode);
+  } else {
+    switch (mode) {
+      case DC_PRED: return 0;
+      case V_PRED: return 1;
+      case H_PRED: return 2;
+      case SMOOTH_PRED: return 3;
+      default: assert(0); return -1;
+    }
+  }
+}
+
 enum {
   // Default initialization when we are not using winner mode framework. e.g.
   // intrabc
@@ -82,7 +115,7 @@ typedef struct RD_OPT {
   double r0;
 } RD_OPT;
 
-static INLINE void av1_init_rd_stats(RD_STATS *rd_stats) {
+static inline void av1_init_rd_stats(RD_STATS *rd_stats) {
 #if CONFIG_RD_DEBUG
   int plane;
 #endif
@@ -101,7 +134,7 @@ static INLINE void av1_init_rd_stats(RD_STATS *rd_stats) {
 #endif
 }
 
-static INLINE void av1_invalid_rd_stats(RD_STATS *rd_stats) {
+static inline void av1_invalid_rd_stats(RD_STATS *rd_stats) {
 #if CONFIG_RD_DEBUG
   int plane;
 #endif
@@ -120,7 +153,7 @@ static INLINE void av1_invalid_rd_stats(RD_STATS *rd_stats) {
 #endif
 }
 
-static INLINE void av1_merge_rd_stats(RD_STATS *rd_stats_dst,
+static inline void av1_merge_rd_stats(RD_STATS *rd_stats_dst,
                                       const RD_STATS *rd_stats_src) {
   if (rd_stats_dst->rate == INT_MAX || rd_stats_src->rate == INT_MAX) {
     // If rd_stats_dst or rd_stats_src has invalid rate, we will make
@@ -133,7 +166,9 @@ static INLINE void av1_merge_rd_stats(RD_STATS *rd_stats_dst,
   if (!rd_stats_dst->zero_rate)
     rd_stats_dst->zero_rate = rd_stats_src->zero_rate;
   rd_stats_dst->dist += rd_stats_src->dist;
-  rd_stats_dst->sse += rd_stats_src->sse;
+  if (rd_stats_dst->sse < INT64_MAX && rd_stats_src->sse < INT64_MAX) {
+    rd_stats_dst->sse += rd_stats_src->sse;
+  }
   rd_stats_dst->skip_txfm &= rd_stats_src->skip_txfm;
 #if CONFIG_RD_DEBUG
   // This may run into problems when monochrome video is
@@ -144,7 +179,7 @@ static INLINE void av1_merge_rd_stats(RD_STATS *rd_stats_dst,
 #endif
 }
 
-static INLINE void av1_accumulate_rd_stats(RD_STATS *rd_stats, int64_t dist,
+static inline void av1_accumulate_rd_stats(RD_STATS *rd_stats, int64_t dist,
                                            int rate, int skip_txfm, int64_t sse,
                                            int zero_rate) {
   assert(rd_stats->rate != INT_MAX && rate != INT_MAX);
@@ -155,7 +190,7 @@ static INLINE void av1_accumulate_rd_stats(RD_STATS *rd_stats, int64_t dist,
   rd_stats->sse += sse;
 }
 
-static INLINE int64_t av1_calculate_rd_cost(int mult, int rate, int64_t dist) {
+static inline int64_t av1_calculate_rd_cost(int mult, int rate, int64_t dist) {
   assert(mult >= 0);
   if (rate >= 0) {
     return RDCOST(mult, rate, dist);
@@ -163,7 +198,7 @@ static INLINE int64_t av1_calculate_rd_cost(int mult, int rate, int64_t dist) {
   return RDCOST_NEG_R(mult, -rate, dist);
 }
 
-static INLINE void av1_rd_cost_update(int mult, RD_STATS *rd_cost) {
+static inline void av1_rd_cost_update(int mult, RD_STATS *rd_cost) {
   if (rd_cost->rate < INT_MAX && rd_cost->dist < INT64_MAX &&
       rd_cost->rdcost < INT64_MAX) {
     rd_cost->rdcost = av1_calculate_rd_cost(mult, rd_cost->rate, rd_cost->dist);
@@ -172,7 +207,7 @@ static INLINE void av1_rd_cost_update(int mult, RD_STATS *rd_cost) {
   }
 }
 
-static INLINE void av1_rd_stats_subtraction(int mult,
+static inline void av1_rd_stats_subtraction(int mult,
                                             const RD_STATS *const left,
                                             const RD_STATS *const right,
                                             RD_STATS *result) {
@@ -197,14 +232,21 @@ struct macroblock;
  * \param[in]       bit_depth       bit depth
  * \param[in]       update_type     frame update type
  * \param[in]       qindex          q index
+ * \param[in]       tuning          visual tuning metric
  *
  * \return rdmult
  */
 int av1_compute_rd_mult_based_on_qindex(aom_bit_depth_t bit_depth,
                                         FRAME_UPDATE_TYPE update_type,
-                                        int qindex);
+                                        int qindex, aom_tune_metric tuning);
 
-int av1_compute_rd_mult(const struct AV1_COMP *cpi, int qindex);
+int av1_compute_rd_mult(const int qindex, const aom_bit_depth_t bit_depth,
+                        const FRAME_UPDATE_TYPE update_type,
+                        const int layer_depth, const int boost_index,
+                        const FRAME_TYPE frame_type,
+                        const int use_fixed_qp_offsets,
+                        const int is_stat_consumption_stage,
+                        const aom_tune_metric tuning);
 
 void av1_initialize_rd_consts(struct AV1_COMP *cpi);
 
@@ -217,8 +259,6 @@ void av1_model_rd_from_var_lapndz(int64_t var, unsigned int n,
 
 void av1_model_rd_curvfit(BLOCK_SIZE bsize, double sse_norm, double xqr,
                           double *rate_f, double *distbysse_f);
-void av1_model_rd_surffit(BLOCK_SIZE bsize, double sse_norm, double xm,
-                          double yl, double *rate_f, double *distbysse_f);
 
 int av1_get_switchable_rate(const MACROBLOCK *x, const MACROBLOCKD *xd,
                             InterpFilter interp_filter, int dual_filter);
@@ -245,7 +285,7 @@ void av1_update_rd_thresh_fact(const AV1_COMMON *const cm,
                                THR_MODES intra_mode_start,
                                THR_MODES intra_mode_end);
 
-static INLINE void reset_thresh_freq_fact(MACROBLOCK *const x) {
+static inline void reset_thresh_freq_fact(MACROBLOCK *const x) {
   for (int i = 0; i < BLOCK_SIZES_ALL; ++i) {
     for (int j = 0; j < MAX_MODES; ++j) {
       x->thresh_freq_fact[i][j] = RD_THRESH_FAC_FRAC_VAL;
@@ -253,7 +293,7 @@ static INLINE void reset_thresh_freq_fact(MACROBLOCK *const x) {
   }
 }
 
-static INLINE int rd_less_than_thresh(int64_t best_rd, int64_t thresh,
+static inline int rd_less_than_thresh(int64_t best_rd, int64_t thresh,
                                       int thresh_fact) {
   return best_rd < (thresh * thresh_fact >> 5) || thresh == INT_MAX;
 }
@@ -263,13 +303,13 @@ void av1_mv_pred(const struct AV1_COMP *cpi, MACROBLOCK *x,
                  BLOCK_SIZE block_size);
 
 // Sets the multiplier to convert mv cost to l2 error during motion search.
-static INLINE void av1_set_error_per_bit(int *errorperbit, int rdmult) {
+static inline void av1_set_error_per_bit(int *errorperbit, int rdmult) {
   *errorperbit = AOMMAX(rdmult >> RD_EPB_SHIFT, 1);
 }
 
 // Get the threshold for R-D optimization of coefficients depending upon mode
 // decision/winner mode processing
-static INLINE void get_rd_opt_coeff_thresh(
+static inline void get_rd_opt_coeff_thresh(
     const uint32_t (*const coeff_opt_threshold)[2],
     TxfmSearchParams *txfm_params, int enable_winner_mode_for_coeff_opt,
     int is_winner_mode) {
@@ -299,7 +339,7 @@ static INLINE void get_rd_opt_coeff_thresh(
 }
 
 // Used to reset the state of mb rd hash information
-static INLINE void reset_mb_rd_record(MB_RD_RECORD *const mb_rd_record) {
+static inline void reset_mb_rd_record(MB_RD_RECORD *const mb_rd_record) {
   if (!mb_rd_record) return;
 
   // Reset the state for use_mb_rd_hash
@@ -319,7 +359,9 @@ int av1_get_intra_cost_penalty(int qindex, int qdelta,
 void av1_fill_mode_rates(AV1_COMMON *const cm, ModeCosts *mode_costs,
                          FRAME_CONTEXT *fc);
 
+#if !CONFIG_REALTIME_ONLY
 void av1_fill_lr_rates(ModeCosts *mode_costs, FRAME_CONTEXT *fc);
+#endif
 
 void av1_fill_coeff_costs(CoeffCosts *coeff_costs, FRAME_CONTEXT *fc,
                           const int num_planes);
@@ -329,7 +371,9 @@ void av1_fill_mv_costs(const nmv_context *nmvc, int integer_mv, int usehp,
 
 void av1_fill_dv_costs(const nmv_context *ndvc, IntraBCMVCosts *dv_costs);
 
+#if !CONFIG_REALTIME_ONLY
 int av1_get_adaptive_rdmult(const struct AV1_COMP *cpi, double beta);
+#endif
 
 int av1_get_deltaq_offset(aom_bit_depth_t bit_depth, int qindex, double beta);
 
